@@ -16,30 +16,30 @@ class GeoBlock(FieldBlock):
     class Meta:
         icon = "site"
 
-    def __init__(
-        self, address_field=None, required=True, help_text=None, **kwargs
-    ):
+    def __init__(self, address_field=None, required=True, help_text=None, **kwargs):
         self.field_options = {}
         self.address_field = address_field
         super(GeoBlock, self).__init__(**kwargs)
 
     @cached_property
     def field(self):
-        field_kwargs = {'widget': GeoField(
-            srid=4326,
-            id_prefix='',
-            address_field=self.address_field,
-            used_in="GeoBlock",
-        )}
+        field_kwargs = {
+            "widget": GeoField(
+                srid=4326,
+                id_prefix="",
+                address_field=self.address_field,
+                used_in="GeoBlock",
+            )
+        }
         field_kwargs.update(self.field_options)
         return forms.CharField(**field_kwargs)
 
-    def render_form(self, value, prefix='', errors=None):
+    def render_form(self, value, prefix="", errors=None):
         if value and isinstance(value, dict):
             value = "SRID={};POINT({} {})".format(
-                value['srid'],
-                value['lng'],
-                value['lat'],
+                value["srid"],
+                value["lng"],
+                value["lat"],
             )
 
         return super(GeoBlock, self).render_form(value, prefix, errors)
@@ -56,8 +56,8 @@ class GeoBlock(FieldBlock):
 
         val = "SRID={};POINT({} {})".format(
             4326,
-            value['lng'],
-            value['lat'],
+            value["lng"],
+            value["lat"],
         )
         return val
 
@@ -67,9 +67,9 @@ class GeoBlock(FieldBlock):
 
         value = geosgeometry_str_to_struct(value)
         value = {
-            'lat': value['y'],
-            'lng': value['x'],
-            'srid': value['srid'],
+            "lat": value["y"],
+            "lng": value["x"],
+            "srid": value["srid"],
         }
 
         return super(GeoBlock, self).to_python(value)
